# Power analyses (06-01-2007)
# Information from lmer fits (max N=4800, max. n sent = 3032)
#           N     a     x1   pv   x1pv   s.it  s.id  s.y
# FFD n  : 2869  198  -7.9   2.5  -3.2    14    26    53
# FFD n+1: 1552  198   9.3   9.2  -5.7    13    24    50
# FFD n+2: 2676  203  -3.1  -1.7  -1.4    13    23    61
# GZD n  : 2914  230 -28.0   6.7 -13.1    29    39    86
# GZD n+1: 1566  204   8.8  11.0  -3.8    20    26    58
# GZD n+2: 2696  237  -3.5   3.6  -6.1    27    37    98
#
# Power analyses for n+2 experiment (Gelman & Hill, 2007)
#
rm(list=ls())
library(lme4)
source("ffd.fake.R")
source("gzd.fake.R")
source("n2power.new.R")

# Kliegl, Risse, & Laubrock (K=160, J=30)
# Rayner, Juhasz, & Brown (K=40, J=36; but: RJB n == KRL n+1?)
prb1 <- 2880/4800  # .60 for n and n+2
prb2 <- 1600/4800  # .33 for n+1
K <- 160
J <-  30

ffd.pow100 <- n2.power(J, K, prop=1.0,   n.sims=1000)    # x1: -7, pv: 7, x1*pv: -7
for (i in 1:3) print(mean(ffd.pow100[,i]))            #  .977,  .979,   .476

#ffd.pow60  <- n2.power(J, K, prop=prb1, n.sims=1000)   
#for (i in 1:3) print(mean(ffd.pow60[,i]))             #  .848,  .877,   .319

#ffd.pow33  <- n2.power(J, K, prop=prb2, n.sims=1000) 
#for (i in 1:3) print(mean(ffd.pow33[,i]))             #  .591,  .598,   .182

ffd.pow60  <- n2.power(J, K, prop=prb1, n.sims=1000)  # x1: -7, pv: 7, x1*pv: -14
for (i in 1:3) print(mean(ffd.pow60[,i]))             #  .865,  .871,   .858

ffd.pow33  <- n2.power(J, K, prop=prb2, n.sims=1000) 
for (i in 1:3) print(mean(ffd.pow33[,i]))             #  .614,  .579,   .631

# Exchange ffd.fake and gzd.fake in n2power.R
gzd.pow60  <- n2.power(J, K, prop=prb1, n.sims=1000)   
for (i in 1:3) print(mean(gzd.pow60[,i]))             #  .511,  .502,   .524

gzd.pow33  <- n2.power(J, K, prop=prb2, n.sims=1000)   
for (i in 1:3) print(mean(gzd.pow33[,i]))             #  .647,  .628,   .627

# Skipping of n+1
ffd.sk.pow60  <- n2.power.sk(J, K, prop=prb1, n.sims=1000)   
for (i in 1:6) print(mean(ffd.sk.pow60[,i]))         

gzd.sk.pow60  <- n2.power.sk(J, K, prop=prb1, n.sims=1000)   
for (i in 1:6) print(mean(gzd.sk.pow60[,i]))         
